@@ -1,14 +1,14 @@
-from vkbottle_types.responses import friends, base
-from typing import Optional, Any, List
+import typing
 from .base_category import BaseCategory
+from vkbottle_types.responses import friends, base
 
 
 class FriendsCategory(BaseCategory):
     async def add(
         self,
-        user_id: Optional[int] = None,
-        text: Optional[str] = None,
-        follow: Optional[bool] = None,
+        user_id: typing.Optional[int] = None,
+        text: typing.Optional[str] = None,
+        follow: typing.Optional[bool] = None,
         **kwargs
     ) -> friends.AddResponseModel:
         """Approves or creates a friend request.
@@ -23,7 +23,7 @@ class FriendsCategory(BaseCategory):
         return model(**response).response
 
     async def add_list(
-        self, name: str, user_ids: Optional[List[int]] = None, **kwargs
+        self, name: str, user_ids: typing.Optional[typing.List[int]] = None, **kwargs
     ) -> friends.AddListResponseModel:
         """Creates a new friend list for the current user.
         :param name: Name of the friend list.
@@ -37,9 +37,9 @@ class FriendsCategory(BaseCategory):
 
     async def are_friends(
         self,
-        user_ids: List[int],
-        need_sign: Optional[bool] = None,
-        extended: Optional[bool] = None,
+        user_ids: typing.List[int],
+        need_sign: typing.Optional[bool] = None,
+        extended: typing.Optional[bool] = None,
         **kwargs
     ) -> friends.AreFriendsResponseModel:
         """Checks the current user's friendship status with other specified users.
@@ -58,7 +58,7 @@ class FriendsCategory(BaseCategory):
         return model(**response).response
 
     async def delete(
-        self, user_id: Optional[int] = None, **kwargs
+        self, user_id: typing.Optional[int] = None, **kwargs
     ) -> friends.DeleteResponseModel:
         """Declines a friend request or deletes a user from the current user's friend list.
         :param user_id: ID of the user whose friend request is to be declined or who is to be deleted from the current user's friend list.
@@ -69,7 +69,9 @@ class FriendsCategory(BaseCategory):
         model = friends.DeleteResponse
         return model(**response).response
 
-    async def delete_all_requests(self, **kwargs) -> base.OkResponseModel:
+    async def delete_all_requests(
+        self, **kwargs
+    ) -> base.OkResponseModel:
         """Marks all incoming friend requests as viewed."""
 
         params = self.get_set_params(locals())
@@ -77,7 +79,9 @@ class FriendsCategory(BaseCategory):
         model = base.OkResponse
         return model(**response).response
 
-    async def delete_list(self, list_id: int, **kwargs) -> base.OkResponseModel:
+    async def delete_list(
+        self, list_id: int, **kwargs
+    ) -> base.OkResponseModel:
         """Deletes a friend list of the current user.
         :param list_id: ID of the friend list to delete.
         """
@@ -88,7 +92,10 @@ class FriendsCategory(BaseCategory):
         return model(**response).response
 
     async def edit(
-        self, user_id: int, list_ids: Optional[List[int]] = None, **kwargs
+        self,
+        user_id: int,
+        list_ids: typing.Optional[typing.List[int]] = None,
+        **kwargs
     ) -> base.OkResponseModel:
         """Edits the friend lists of the selected user.
         :param user_id: ID of the user whose friend list is to be edited.
@@ -103,10 +110,10 @@ class FriendsCategory(BaseCategory):
     async def edit_list(
         self,
         list_id: int,
-        name: Optional[str] = None,
-        user_ids: Optional[List[int]] = None,
-        add_user_ids: Optional[List[int]] = None,
-        delete_user_ids: Optional[List[int]] = None,
+        name: typing.Optional[str] = None,
+        user_ids: typing.Optional[typing.List[int]] = None,
+        add_user_ids: typing.Optional[typing.List[int]] = None,
+        delete_user_ids: typing.Optional[typing.List[int]] = None,
         **kwargs
     ) -> base.OkResponseModel:
         """Edits a friend list of the current user.
@@ -124,14 +131,14 @@ class FriendsCategory(BaseCategory):
 
     async def get(
         self,
-        user_id: Optional[int] = None,
-        order: Optional[str] = None,
-        list_id: Optional[int] = None,
-        count: Optional[int] = None,
-        offset: Optional[int] = None,
-        fields: Optional[List[str]] = None,
-        name_case: Optional[str] = None,
-        ref: Optional[str] = None,
+        user_id: typing.Optional[int] = None,
+        order: typing.Optional[str] = None,
+        list_id: typing.Optional[int] = None,
+        count: typing.Optional[int] = None,
+        offset: typing.Optional[int] = None,
+        fields: typing.Optional[typing.List[str]] = None,
+        name_case: typing.Optional[str] = None,
+        ref: typing.Optional[str] = None,
         **kwargs
     ) -> friends.GetResponseModel:
         """Returns a list of user IDs or detailed information about a user's friends.
@@ -147,14 +154,12 @@ class FriendsCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("friends.get", params)
-        model = self.get_model(
-            {("fields",): friends.GetFieldsResponse},
-            default=friends.GetResponse,
-            params=params,
-        )
+        model = friends.GetResponse
         return model(**response).response
 
-    async def get_app_users(self, **kwargs) -> friends.GetAppUsersResponseModel:
+    async def get_app_users(
+        self, **kwargs
+    ) -> friends.GetAppUsersResponseModel:
         """Returns a list of IDs of the current user's friends who installed the application."""
 
         params = self.get_set_params(locals())
@@ -164,8 +169,8 @@ class FriendsCategory(BaseCategory):
 
     async def get_by_phones(
         self,
-        phones: Optional[List[str]] = None,
-        fields: Optional[List[str]] = None,
+        phones: typing.Optional[typing.List[str]] = None,
+        fields: typing.Optional[typing.List[str]] = None,
         **kwargs
     ) -> friends.GetByPhonesResponseModel:
         """Returns a list of the current user's friends whose phone numbers, validated or specified in a profile, are in a given list.
@@ -180,8 +185,8 @@ class FriendsCategory(BaseCategory):
 
     async def get_lists(
         self,
-        user_id: Optional[int] = None,
-        return_system: Optional[bool] = None,
+        user_id: typing.Optional[int] = None,
+        return_system: typing.Optional[bool] = None,
         **kwargs
     ) -> friends.GetListsResponseModel:
         """Returns a list of the user's friend lists.
@@ -196,12 +201,12 @@ class FriendsCategory(BaseCategory):
 
     async def get_mutual(
         self,
-        source_uid: Optional[int] = None,
-        target_uid: Optional[int] = None,
-        target_uids: Optional[List[int]] = None,
-        order: Optional[str] = None,
-        count: Optional[int] = None,
-        offset: Optional[int] = None,
+        source_uid: typing.Optional[int] = None,
+        target_uid: typing.Optional[int] = None,
+        target_uids: typing.Optional[typing.List[int]] = None,
+        order: typing.Optional[str] = None,
+        count: typing.Optional[int] = None,
+        offset: typing.Optional[int] = None,
         **kwargs
     ) -> friends.GetMutualResponseModel:
         """Returns a list of user IDs of the mutual friends of two users.
@@ -215,21 +220,17 @@ class FriendsCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("friends.getMutual", params)
-        model = self.get_model(
-            {("target_uids",): friends.GetMutualTargetUidsResponse},
-            default=friends.GetMutualResponse,
-            params=params,
-        )
+        model = friends.GetMutualResponse
         return model(**response).response
 
     async def get_online(
         self,
-        user_id: Optional[int] = None,
-        list_id: Optional[int] = None,
-        online_mobile: Optional[bool] = None,
-        order: Optional[str] = None,
-        count: Optional[int] = None,
-        offset: Optional[int] = None,
+        user_id: typing.Optional[int] = None,
+        list_id: typing.Optional[int] = None,
+        online_mobile: typing.Optional[bool] = None,
+        order: typing.Optional[str] = None,
+        count: typing.Optional[int] = None,
+        offset: typing.Optional[int] = None,
         **kwargs
     ) -> friends.GetOnlineResponseModel:
         """Returns a list of user IDs of a user's friends who are online.
@@ -243,15 +244,11 @@ class FriendsCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("friends.getOnline", params)
-        model = self.get_model(
-            {("online_mobile",): friends.GetOnlineOnlineMobileResponse},
-            default=friends.GetOnlineResponse,
-            params=params,
-        )
+        model = friends.GetOnlineResponse
         return model(**response).response
 
     async def get_recent(
-        self, count: Optional[int] = None, **kwargs
+        self, count: typing.Optional[int] = None, **kwargs
     ) -> friends.GetRecentResponseModel:
         """Returns a list of user IDs of the current user's recently added friends.
         :param count: Number of recently added friends to return.
@@ -264,16 +261,16 @@ class FriendsCategory(BaseCategory):
 
     async def get_requests(
         self,
-        offset: Optional[int] = None,
-        count: Optional[int] = None,
-        extended: Optional[bool] = None,
-        need_mutual: Optional[bool] = None,
-        out: Optional[bool] = None,
-        sort: Optional[int] = None,
-        need_viewed: Optional[bool] = None,
-        suggested: Optional[bool] = None,
-        ref: Optional[str] = None,
-        fields: Optional[List[str]] = None,
+        offset: typing.Optional[int] = None,
+        count: typing.Optional[int] = None,
+        extended: typing.Optional[bool] = None,
+        need_mutual: typing.Optional[bool] = None,
+        out: typing.Optional[bool] = None,
+        sort: typing.Optional[int] = None,
+        need_viewed: typing.Optional[bool] = None,
+        suggested: typing.Optional[bool] = None,
+        ref: typing.Optional[str] = None,
+        fields: typing.Optional[typing.List[str]] = None,
         **kwargs
     ) -> friends.GetRequestsResponseModel:
         """Returns information about the current user's incoming and outgoing friend requests.
@@ -292,10 +289,7 @@ class FriendsCategory(BaseCategory):
         params = self.get_set_params(locals())
         response = await self.api.request("friends.getRequests", params)
         model = self.get_model(
-            {
-                ("need_mutual",): friends.GetRequestsNeedMutualResponse,
-                ("extended",): friends.GetRequestsExtendedResponse,
-            },
+            {("extended",): friends.GetRequestsExtendedResponse},
             default=friends.GetRequestsResponse,
             params=params,
         )
@@ -303,11 +297,11 @@ class FriendsCategory(BaseCategory):
 
     async def get_suggestions(
         self,
-        filter: Optional[List[str]] = None,
-        count: Optional[int] = None,
-        offset: Optional[int] = None,
-        fields: Optional[List[str]] = None,
-        name_case: Optional[str] = None,
+        filter: typing.Optional[typing.List[str]] = None,
+        count: typing.Optional[int] = None,
+        offset: typing.Optional[int] = None,
+        fields: typing.Optional[typing.List[str]] = None,
+        name_case: typing.Optional[str] = None,
         **kwargs
     ) -> friends.GetSuggestionsResponseModel:
         """Returns a list of profiles of users whom the current user may know.
@@ -326,11 +320,11 @@ class FriendsCategory(BaseCategory):
     async def search(
         self,
         user_id: int,
-        q: Optional[str] = None,
-        fields: Optional[List[str]] = None,
-        name_case: Optional[str] = None,
-        offset: Optional[int] = None,
-        count: Optional[int] = None,
+        q: typing.Optional[str] = None,
+        fields: typing.Optional[typing.List[str]] = None,
+        name_case: typing.Optional[str] = None,
+        offset: typing.Optional[int] = None,
+        count: typing.Optional[int] = None,
         **kwargs
     ) -> friends.SearchResponseModel:
         """Returns a list of friends matching the search criteria.
